#include "../../base.shader"

struct VERT_INPUT_ANIMATED
{
	float4 location : POSITION;
	float4 color : COLOR0;
	float2 uv : TEXCOORD0;
	float horizontalUVOffsetPerFrame : NORMAL0;
	float animationInterval : NORMAL1;
	float animationStartTime : NORMAL2;
	float animationFrames : NORMAL3;
};

float4x4 _transform;
float _gameTime;
VERT_OUTPUT vert(in VERT_INPUT_ANIMATED input)
{
	VERT_OUTPUT output;
	output.location = mul(input.location, _transform);
	output.color = input.color;
	output.uv.y = input.uv.y;
	int frame = (int)((_gameTime - input.animationStartTime) / input.animationInterval) % (int)input.animationFrames;
	output.uv.x = input.uv.x + input.horizontalUVOffsetPerFrame * frame;
	return output;
}

sampler2D _texture;
float4 _color;
float4 _allegianceColor;
PIX_OUTPUT pix(in PIX_INPUT input) : COLOR0
{
	float4 pixel = tex2D(_texture, input.uv);
	if(pixel.g > pixel.r && abs(pixel.r - pixel.b) < .025) // Replace green pixels with allegiance color.
	{
		float3 scaledAllegianceColor = _allegianceColor.rgb * pixel.g;
		float desaturation = pixel.r / pixel.g; // works because pixel.r == pixel.b (approximately)
		float desaturationValue = max(scaledAllegianceColor.r, max(scaledAllegianceColor.g, scaledAllegianceColor.b));
		float3 desaturationColor = float3(desaturationValue, desaturationValue, desaturationValue);
		pixel.rgb = scaledAllegianceColor * (1 - desaturation) + desaturationColor * desaturation;
	}

	return pixel * input.color * _color;
}
